pub struct RemoteDirectory { /* private fields */ }Expand description
RemoteDirectory supports iteration of directories and things that you can do to directories via
a file descriptor. Other opterations, such as creating children, can be done via RemoteIo.
Iteration is not safe to be done concurrently because there is a seek pointer; readdir will
resume from the seek position.
Implementations
Sourceimpl RemoteDirectory
impl RemoteDirectory
pub fn new(proxy: DirectorySynchronousProxy) -> Self
Sourcepub fn readdir<B, S: FnMut(u64, DirentType, &[u8]) -> ControlFlow<B, ()>>(
&self,
sink: S,
) -> Result<Option<B>, Status>
pub fn readdir<B, S: FnMut(u64, DirentType, &[u8]) -> ControlFlow<B, ()>>( &self, sink: S, ) -> Result<Option<B>, Status>
Returns None if there are no more entries to be read. sink can choose to return
ControlFlow::Break(_) in which case the entry will be returned the next time readdir is
called.
Sourcepub fn clone_proxy(&self) -> Result<DirectorySynchronousProxy, Status>
pub fn clone_proxy(&self) -> Result<DirectorySynchronousProxy, Status>
Clones (in the fuchsia.unknown.Clonable sense) the underlying proxy.